from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import sys
import threads_pb2
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class ThreadsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetThread(
        self,
        request: threads_pb2.GetThreadReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[threads_pb2.GetThreadRes, collections.abc.Awaitable[threads_pb2.GetThreadRes]]:
        """The same API is used regardless of level. All posts are using the same id namespace.

        Get non-deleted posts belonging to a thread, sorted in reverse time order.
        """

    @abc.abstractmethod
    def PostReply(
        self,
        request: threads_pb2.PostReplyReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[threads_pb2.PostReplyRes, collections.abc.Awaitable[threads_pb2.PostReplyRes]]:
        """Post a new comment on a thread. The post can not be changed or deleted after posting.
        Throws NOT_FOUND if thread_id corresponds to a nesting level 3 reply, since no futher nesting is allowed.
        """

def add_ThreadsServicer_to_server(servicer: ThreadsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetNotificationSettingsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetNotificationSettingsReq: typing_extensions.TypeAlias = GetNotificationSettingsReq

@typing.final
class NotificationItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    USER_EDITABLE_FIELD_NUMBER: builtins.int
    PUSH_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    action: builtins.str
    """e.g. "complete" for account recovery"""
    description: builtins.str
    """e.g. "Password reset is completed" """
    user_editable: builtins.bool
    """whether this is user editable"""
    push: builtins.bool
    email: builtins.bool
    digest: builtins.bool
    def __init__(
        self,
        *,
        action: builtins.str | None = ...,
        description: builtins.str | None = ...,
        user_editable: builtins.bool | None = ...,
        push: builtins.bool | None = ...,
        email: builtins.bool | None = ...,
        digest: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "description", b"description", "digest", b"digest", "email", b"email", "push", b"push", "user_editable", b"user_editable"]) -> None: ...

Global___NotificationItem: typing_extensions.TypeAlias = NotificationItem

@typing.final
class NotificationTopic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    topic: builtins.str
    """e.g. "badge" """
    name: builtins.str
    """e.g. "Profile badges" """
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___NotificationItem]:
        """items in this topic"""

    def __init__(
        self,
        *,
        topic: builtins.str | None = ...,
        name: builtins.str | None = ...,
        items: collections.abc.Iterable[Global___NotificationItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["items", b"items", "name", b"name", "topic", b"topic"]) -> None: ...

Global___NotificationTopic: typing_extensions.TypeAlias = NotificationTopic

@typing.final
class NotificationGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADING_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    heading: builtins.str
    """a set of notification topics grouped together, e.g. "Account Settings" """
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___NotificationTopic]: ...
    def __init__(
        self,
        *,
        heading: builtins.str | None = ...,
        topics: collections.abc.Iterable[Global___NotificationTopic] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["heading", b"heading", "topics", b"topics"]) -> None: ...

Global___NotificationGroup: typing_extensions.TypeAlias = NotificationGroup

@typing.final
class SingleNotificationPreference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    DELIVERY_METHOD_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    topic: builtins.str
    action: builtins.str
    delivery_method: builtins.str
    """one of "push"/"email"/"digest" """
    enabled: builtins.bool
    def __init__(
        self,
        *,
        topic: builtins.str | None = ...,
        action: builtins.str | None = ...,
        delivery_method: builtins.str | None = ...,
        enabled: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "delivery_method", b"delivery_method", "enabled", b"enabled", "topic", b"topic"]) -> None: ...

Global___SingleNotificationPreference: typing_extensions.TypeAlias = SingleNotificationPreference

@typing.final
class GetNotificationSettingsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DO_NOT_EMAIL_ENABLED_FIELD_NUMBER: builtins.int
    EMAIL_DIGEST_ENABLED_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    do_not_email_enabled: builtins.bool
    email_digest_enabled: builtins.bool
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___NotificationGroup]: ...
    def __init__(
        self,
        *,
        do_not_email_enabled: builtins.bool | None = ...,
        email_digest_enabled: builtins.bool | None = ...,
        groups: collections.abc.Iterable[Global___NotificationGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["do_not_email_enabled", b"do_not_email_enabled", "email_digest_enabled", b"email_digest_enabled", "groups", b"groups"]) -> None: ...

Global___GetNotificationSettingsRes: typing_extensions.TypeAlias = GetNotificationSettingsRes

@typing.final
class SetNotificationSettingsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_DO_NOT_EMAIL_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    enable_do_not_email: builtins.bool
    @property
    def preferences(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___SingleNotificationPreference]:
        """an arbitray list of these, they are applied consequtively, any errors will error out the whole thing"""

    def __init__(
        self,
        *,
        enable_do_not_email: builtins.bool | None = ...,
        preferences: collections.abc.Iterable[Global___SingleNotificationPreference] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["enable_do_not_email", b"enable_do_not_email", "preferences", b"preferences"]) -> None: ...

Global___SetNotificationSettingsReq: typing_extensions.TypeAlias = SetNotificationSettingsReq

@typing.final
class Notification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_ID_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    IS_SEEN_FIELD_NUMBER: builtins.int
    notification_id: builtins.int
    topic: builtins.str
    action: builtins.str
    key: builtins.str
    title: builtins.str
    body: builtins.str
    icon: builtins.str
    url: builtins.str
    is_seen: builtins.bool
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        notification_id: builtins.int | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        topic: builtins.str | None = ...,
        action: builtins.str | None = ...,
        key: builtins.str | None = ...,
        title: builtins.str | None = ...,
        body: builtins.str | None = ...,
        icon: builtins.str | None = ...,
        url: builtins.str | None = ...,
        is_seen: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "body", b"body", "created", b"created", "icon", b"icon", "is_seen", b"is_seen", "key", b"key", "notification_id", b"notification_id", "title", b"title", "topic", b"topic", "url", b"url"]) -> None: ...

Global___Notification: typing_extensions.TypeAlias = Notification

@typing.final
class ListNotificationsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLY_UNREAD_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    only_unread: builtins.bool
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        only_unread: builtins.bool | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["only_unread", b"only_unread", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

Global___ListNotificationsReq: typing_extensions.TypeAlias = ListNotificationsReq

@typing.final
class ListNotificationsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def notifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Notification]: ...
    def __init__(
        self,
        *,
        notifications: collections.abc.Iterable[Global___Notification] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "notifications", b"notifications"]) -> None: ...

Global___ListNotificationsRes: typing_extensions.TypeAlias = ListNotificationsRes

@typing.final
class MarkNotificationSeenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_ID_FIELD_NUMBER: builtins.int
    SET_SEEN_FIELD_NUMBER: builtins.int
    notification_id: builtins.int
    set_seen: builtins.bool
    def __init__(
        self,
        *,
        notification_id: builtins.int | None = ...,
        set_seen: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["notification_id", b"notification_id", "set_seen", b"set_seen"]) -> None: ...

Global___MarkNotificationSeenReq: typing_extensions.TypeAlias = MarkNotificationSeenReq

@typing.final
class MarkAllNotificationsSeenReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LATEST_NOTIFICATION_ID_FIELD_NUMBER: builtins.int
    latest_notification_id: builtins.int
    """mark all notifications up to and including this one as seen"""
    def __init__(
        self,
        *,
        latest_notification_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["latest_notification_id", b"latest_notification_id"]) -> None: ...

Global___MarkAllNotificationsSeenReq: typing_extensions.TypeAlias = MarkAllNotificationsSeenReq

@typing.final
class GetVapidPublicKeyRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAPID_PUBLIC_KEY_FIELD_NUMBER: builtins.int
    vapid_public_key: builtins.str
    def __init__(
        self,
        *,
        vapid_public_key: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["vapid_public_key", b"vapid_public_key"]) -> None: ...

Global___GetVapidPublicKeyRes: typing_extensions.TypeAlias = GetVapidPublicKeyRes

@typing.final
class RegisterPushNotificationSubscriptionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_SUBSCRIPTION_JSON_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    full_subscription_json: builtins.str
    """the output of JSON.stirngify() on a ServiceWorkerRegistration.pushManager.subscribe
    see also: https://developer.mozilla.org/en-US/docs/Web/API/PushSubscription
    """
    user_agent: builtins.str
    """the browse user-agent, so we can tell the user what browser notifications are going to"""
    def __init__(
        self,
        *,
        full_subscription_json: builtins.str | None = ...,
        user_agent: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["full_subscription_json", b"full_subscription_json", "user_agent", b"user_agent"]) -> None: ...

Global___RegisterPushNotificationSubscriptionReq: typing_extensions.TypeAlias = RegisterPushNotificationSubscriptionReq

@typing.final
class RegisterMobilePushNotificationSubscriptionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    token: builtins.str
    """Expo push token or platform-specific token"""
    device_name: builtins.str
    """Optional metadata to show users which device is registered"""
    device_type: builtins.str
    """e.g. "ios" or "android" """
    def __init__(
        self,
        *,
        token: builtins.str | None = ...,
        device_name: builtins.str | None = ...,
        device_type: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_name", b"device_name", "device_type", b"device_type", "token", b"token"]) -> None: ...

Global___RegisterMobilePushNotificationSubscriptionReq: typing_extensions.TypeAlias = RegisterMobilePushNotificationSubscriptionReq



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import postal_verification_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class PostalVerificationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def InitiatePostalVerification(
        self,
        request: postal_verification_pb2.InitiatePostalVerificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[postal_verification_pb2.InitiatePostalVerificationRes, collections.abc.Awaitable[postal_verification_pb2.InitiatePostalVerificationRes]]:
        """Step 1: Submit address for validation
        Validates and normalizes the address. Returns a corrected address for user confirmation.
        Returns FAILED_PRECONDITION if there's already an active attempt.
        Returns RESOURCE_EXHAUSTED if rate limited (one attempt per 30 days).
        """

    @abc.abstractmethod
    def ConfirmPostalAddress(
        self,
        request: postal_verification_pb2.ConfirmPostalAddressReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[postal_verification_pb2.ConfirmPostalAddressRes, collections.abc.Awaitable[postal_verification_pb2.ConfirmPostalAddressRes]]:
        """Step 2: Confirm the (possibly corrected) address and send postcard
        Confirms the address and queues postcard for sending.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not in pending_address_confirmation state.
        """

    @abc.abstractmethod
    def GetPostalVerificationStatus(
        self,
        request: postal_verification_pb2.GetPostalVerificationStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[postal_verification_pb2.GetPostalVerificationStatusRes, collections.abc.Awaitable[postal_verification_pb2.GetPostalVerificationStatusRes]]:
        """Get current postal verification status
        Returns the user's postal verification status and current/latest attempt details.
        """

    @abc.abstractmethod
    def VerifyPostalCode(
        self,
        request: postal_verification_pb2.VerifyPostalCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[postal_verification_pb2.VerifyPostalCodeRes, collections.abc.Awaitable[postal_verification_pb2.VerifyPostalCodeRes]]:
        """Submit verification code (from postcard or QR code)
        Verifies the code from the postcard.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not in awaiting_verification state.
        """

    @abc.abstractmethod
    def CancelPostalVerification(
        self,
        request: postal_verification_pb2.CancelPostalVerificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Cancel an in-progress attempt
        Cancels an active postal verification attempt.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not cancellable.
        """

    @abc.abstractmethod
    def ListPostalVerificationAttempts(
        self,
        request: postal_verification_pb2.ListPostalVerificationAttemptsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[postal_verification_pb2.ListPostalVerificationAttemptsRes, collections.abc.Awaitable[postal_verification_pb2.ListPostalVerificationAttemptsRes]]:
        """List all postal verification attempts (history)
        Returns all postal verification attempts for the user.
        """

def add_PostalVerificationServicer_to_server(servicer: PostalVerificationServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import account_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ActivenessProbeResponse:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ActivenessProbeResponseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ActivenessProbeResponse.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACTIVENESS_PROBE_RESPONSE_UNKNOWN: _ActivenessProbeResponse.ValueType  # 0
    ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE: _ActivenessProbeResponse.ValueType  # 1
    ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE: _ActivenessProbeResponse.ValueType  # 2

class ActivenessProbeResponse(_ActivenessProbeResponse, metaclass=_ActivenessProbeResponseEnumTypeWrapper): ...

ACTIVENESS_PROBE_RESPONSE_UNKNOWN: ActivenessProbeResponse.ValueType  # 0
ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE: ActivenessProbeResponse.ValueType  # 1
ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE: ActivenessProbeResponse.ValueType  # 2
Global___ActivenessProbeResponse: typing_extensions.TypeAlias = ActivenessProbeResponse

@typing.final
class JailInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JAILED_FIELD_NUMBER: builtins.int
    HAS_NOT_ACCEPTED_TOS_FIELD_NUMBER: builtins.int
    NEEDS_TO_UPDATE_LOCATION_FIELD_NUMBER: builtins.int
    HAS_NOT_ACCEPTED_COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    HAS_PENDING_MOD_NOTES_FIELD_NUMBER: builtins.int
    PENDING_MOD_NOTES_FIELD_NUMBER: builtins.int
    HAS_PENDING_ACTIVENESS_PROBE_FIELD_NUMBER: builtins.int
    jailed: builtins.bool
    has_not_accepted_tos: builtins.bool
    needs_to_update_location: builtins.bool
    has_not_accepted_community_guidelines: builtins.bool
    has_pending_mod_notes: builtins.bool
    """mod notes"""
    has_pending_activeness_probe: builtins.bool
    @property
    def pending_mod_notes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[account_pb2.ModNote]:
        """the actual mod notes, if any
        will be empty iff has_mode_notes is false
        """

    def __init__(
        self,
        *,
        jailed: builtins.bool | None = ...,
        has_not_accepted_tos: builtins.bool | None = ...,
        needs_to_update_location: builtins.bool | None = ...,
        has_not_accepted_community_guidelines: builtins.bool | None = ...,
        has_pending_mod_notes: builtins.bool | None = ...,
        pending_mod_notes: collections.abc.Iterable[account_pb2.ModNote] | None = ...,
        has_pending_activeness_probe: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["has_not_accepted_community_guidelines", b"has_not_accepted_community_guidelines", "has_not_accepted_tos", b"has_not_accepted_tos", "has_pending_activeness_probe", b"has_pending_activeness_probe", "has_pending_mod_notes", b"has_pending_mod_notes", "jailed", b"jailed", "needs_to_update_location", b"needs_to_update_location", "pending_mod_notes", b"pending_mod_notes"]) -> None: ...

Global___JailInfoRes: typing_extensions.TypeAlias = JailInfoRes

@typing.final
class AcceptTOSReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPT_FIELD_NUMBER: builtins.int
    accept: builtins.bool
    def __init__(
        self,
        *,
        accept: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["accept", b"accept"]) -> None: ...

Global___AcceptTOSReq: typing_extensions.TypeAlias = AcceptTOSReq

@typing.final
class SetLocationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CITY_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    city: builtins.str
    lat: builtins.float
    lng: builtins.float
    radius: builtins.float
    """meters"""
    def __init__(
        self,
        *,
        city: builtins.str | None = ...,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
        radius: builtins.float | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["city", b"city", "lat", b"lat", "lng", b"lng", "radius", b"radius"]) -> None: ...

Global___SetLocationReq: typing_extensions.TypeAlias = SetLocationReq

@typing.final
class AcceptCommunityGuidelinesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPT_FIELD_NUMBER: builtins.int
    accept: builtins.bool
    def __init__(
        self,
        *,
        accept: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["accept", b"accept"]) -> None: ...

Global___AcceptCommunityGuidelinesReq: typing_extensions.TypeAlias = AcceptCommunityGuidelinesReq

@typing.final
class AcknowledgePendingModNoteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTE_ID_FIELD_NUMBER: builtins.int
    ACKNOWLEDGE_FIELD_NUMBER: builtins.int
    note_id: builtins.int
    acknowledge: builtins.bool
    """whether the user acknowledges the note or not"""
    def __init__(
        self,
        *,
        note_id: builtins.int | None = ...,
        acknowledge: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["acknowledge", b"acknowledge", "note_id", b"note_id"]) -> None: ...

Global___AcknowledgePendingModNoteReq: typing_extensions.TypeAlias = AcknowledgePendingModNoteReq

@typing.final
class RespondToActivenessProbeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: Global___ActivenessProbeResponse.ValueType
    def __init__(
        self,
        *,
        response: Global___ActivenessProbeResponse.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RespondToActivenessProbeReq: typing_extensions.TypeAlias = RespondToActivenessProbeReq



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class GISStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUsers = channel.unary_unary(
                '/org.couchers.json.GIS/GetUsers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GetClusteredUsers = channel.unary_unary(
                '/org.couchers.json.GIS/GetClusteredUsers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GetCommunities = channel.unary_unary(
                '/org.couchers.json.GIS/GetCommunities',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GetPlaces = channel.unary_unary(
                '/org.couchers.json.GIS/GetPlaces',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )
        self.GetGuides = channel.unary_unary(
                '/org.couchers.json.GIS/GetGuides',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
                )


class GISServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusteredUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCommunities(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGuides(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GISServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GetClusteredUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusteredUsers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GetCommunities': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCommunities,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GetPlaces': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlaces,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
            'GetGuides': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGuides,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_api_dot_httpbody__pb2.HttpBody.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.json.GIS', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GIS(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.json.GIS/GetUsers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusteredUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.json.GIS/GetClusteredUsers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCommunities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.json.GIS/GetCommunities',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPlaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.json.GIS/GetPlaces',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGuides(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.json.GIS/GetGuides',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_api_dot_httpbody__pb2.HttpBody.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notifications.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13notifications.proto\x12\x1aorg.couchers.notifications\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x1c\n\x1aGetNotificationSettingsReq\"{\n\x10NotificationItem\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\ruser_editable\x18\x03 \x01(\x08\x12\x0c\n\x04push\x18\x04 \x01(\x08\x12\r\n\x05\x65mail\x18\x05 \x01(\x08\x12\x0e\n\x06\x64igest\x18\x06 \x01(\x08\"m\n\x11NotificationTopic\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05items\x18\x03 \x03(\x0b\x32,.org.couchers.notifications.NotificationItem\"c\n\x11NotificationGroup\x12\x0f\n\x07heading\x18\x01 \x01(\t\x12=\n\x06topics\x18\x02 \x03(\x0b\x32-.org.couchers.notifications.NotificationTopic\"g\n\x1cSingleNotificationPreference\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65livery_method\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\"\x97\x01\n\x1aGetNotificationSettingsRes\x12\x1c\n\x14\x64o_not_email_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14\x65mail_digest_enabled\x18\x02 \x01(\x08\x12=\n\x06groups\x18\x03 \x03(\x0b\x32-.org.couchers.notifications.NotificationGroup\"\x88\x01\n\x1aSetNotificationSettingsReq\x12\x1b\n\x13\x65nable_do_not_email\x18\x01 \x01(\x08\x12M\n\x0bpreferences\x18\x02 \x03(\x0b\x32\x38.org.couchers.notifications.SingleNotificationPreference\"\xc9\x01\n\x0cNotification\x12\x17\n\x0fnotification_id\x18\x01 \x01(\x03\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x0f\n\x07is_seen\x18\n \x01(\x08\"R\n\x14ListNotificationsReq\x12\x13\n\x0bonly_unread\x18\x03 \x01(\x08\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"p\n\x14ListNotificationsRes\x12?\n\rnotifications\x18\x01 \x03(\x0b\x32(.org.couchers.notifications.Notification\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"D\n\x17MarkNotificationSeenReq\x12\x17\n\x0fnotification_id\x18\x01 \x01(\x03\x12\x10\n\x08set_seen\x18\x02 \x01(\x08\"=\n\x1bMarkAllNotificationsSeenReq\x12\x1e\n\x16latest_notification_id\x18\x01 \x01(\x03\"0\n\x14GetVapidPublicKeyRes\x12\x18\n\x10vapid_public_key\x18\x01 \x01(\t\"]\n\'RegisterPushNotificationSubscriptionReq\x12\x1e\n\x16\x66ull_subscription_json\x18\x01 \x01(\t\x12\x12\n\nuser_agent\x18\x02 \x01(\t\"h\n-RegisterMobilePushNotificationSubscriptionReq\x12\r\n\x05token\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t2\x8d\t\n\rNotifications\x12\x89\x01\n\x17GetNotificationSettings\x12\x36.org.couchers.notifications.GetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12\x89\x01\n\x17SetNotificationSettings\x12\x36.org.couchers.notifications.SetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12w\n\x11ListNotifications\x12\x30.org.couchers.notifications.ListNotificationsReq\x1a\x30.org.couchers.notifications.ListNotificationsRes\x12\x63\n\x14MarkNotificationSeen\x12\x33.org.couchers.notifications.MarkNotificationSeenReq\x1a\x16.google.protobuf.Empty\x12k\n\x18MarkAllNotificationsSeen\x12\x37.org.couchers.notifications.MarkAllNotificationsSeenReq\x1a\x16.google.protobuf.Empty\x12]\n\x11GetVapidPublicKey\x12\x16.google.protobuf.Empty\x1a\x30.org.couchers.notifications.GetVapidPublicKeyRes\x12\x83\x01\n$RegisterPushNotificationSubscription\x12\x43.org.couchers.notifications.RegisterPushNotificationSubscriptionReq\x1a\x16.google.protobuf.Empty\x12J\n\x18SendTestPushNotification\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12\x8f\x01\n*RegisterMobilePushNotificationSubscription\x12I.org.couchers.notifications.RegisterMobilePushNotificationSubscriptionReq\x1a\x16.google.protobuf.Empty\x12P\n\x1eSendTestMobilePushNotification\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NOTIFICATIONS']._loaded_options = None
  _globals['_NOTIFICATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_start=132
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_end=160
  _globals['_NOTIFICATIONITEM']._serialized_start=162
  _globals['_NOTIFICATIONITEM']._serialized_end=285
  _globals['_NOTIFICATIONTOPIC']._serialized_start=287
  _globals['_NOTIFICATIONTOPIC']._serialized_end=396
  _globals['_NOTIFICATIONGROUP']._serialized_start=398
  _globals['_NOTIFICATIONGROUP']._serialized_end=497
  _globals['_SINGLENOTIFICATIONPREFERENCE']._serialized_start=499
  _globals['_SINGLENOTIFICATIONPREFERENCE']._serialized_end=602
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_start=605
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_end=756
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_start=759
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_end=895
  _globals['_NOTIFICATION']._serialized_start=898
  _globals['_NOTIFICATION']._serialized_end=1099
  _globals['_LISTNOTIFICATIONSREQ']._serialized_start=1101
  _globals['_LISTNOTIFICATIONSREQ']._serialized_end=1183
  _globals['_LISTNOTIFICATIONSRES']._serialized_start=1185
  _globals['_LISTNOTIFICATIONSRES']._serialized_end=1297
  _globals['_MARKNOTIFICATIONSEENREQ']._serialized_start=1299
  _globals['_MARKNOTIFICATIONSEENREQ']._serialized_end=1367
  _globals['_MARKALLNOTIFICATIONSSEENREQ']._serialized_start=1369
  _globals['_MARKALLNOTIFICATIONSSEENREQ']._serialized_end=1430
  _globals['_GETVAPIDPUBLICKEYRES']._serialized_start=1432
  _globals['_GETVAPIDPUBLICKEYRES']._serialized_end=1480
  _globals['_REGISTERPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_start=1482
  _globals['_REGISTERPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_end=1575
  _globals['_REGISTERMOBILEPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_start=1577
  _globals['_REGISTERMOBILEPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_end=1681
  _globals['_NOTIFICATIONS']._serialized_start=1684
  _globals['_NOTIFICATIONS']._serialized_end=2849
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import communities_pb2
import editor_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class EditorServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateCommunity(
        self,
        request: editor_pb2.CreateCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[communities_pb2.Community, collections.abc.Awaitable[communities_pb2.Community]]: ...

    @abc.abstractmethod
    def UpdateCommunity(
        self,
        request: editor_pb2.UpdateCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[communities_pb2.Community, collections.abc.Awaitable[communities_pb2.Community]]: ...

    @abc.abstractmethod
    def ListEventCommunityInviteRequests(
        self,
        request: editor_pb2.ListEventCommunityInviteRequestsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.ListEventCommunityInviteRequestsRes, collections.abc.Awaitable[editor_pb2.ListEventCommunityInviteRequestsRes]]: ...

    @abc.abstractmethod
    def DecideEventCommunityInviteRequest(
        self,
        request: editor_pb2.DecideEventCommunityInviteRequestReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.DecideEventCommunityInviteRequestRes, collections.abc.Awaitable[editor_pb2.DecideEventCommunityInviteRequestRes]]: ...

    @abc.abstractmethod
    def SendBlogPostNotification(
        self,
        request: editor_pb2.SendBlogPostNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def MakeUserVolunteer(
        self,
        request: editor_pb2.MakeUserVolunteerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.Volunteer, collections.abc.Awaitable[editor_pb2.Volunteer]]: ...

    @abc.abstractmethod
    def UpdateVolunteer(
        self,
        request: editor_pb2.UpdateVolunteerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.Volunteer, collections.abc.Awaitable[editor_pb2.Volunteer]]: ...

    @abc.abstractmethod
    def ListVolunteers(
        self,
        request: editor_pb2.ListVolunteersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.ListVolunteersRes, collections.abc.Awaitable[editor_pb2.ListVolunteersRes]]: ...

def add_EditorServicer_to_server(servicer: EditorServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import references_pb2 as references__pb2


class ReferencesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListReferences = channel.unary_unary(
                '/org.couchers.api.references.References/ListReferences',
                request_serializer=references__pb2.ListReferencesReq.SerializeToString,
                response_deserializer=references__pb2.ListReferencesRes.FromString,
                )
        self.WriteFriendReference = channel.unary_unary(
                '/org.couchers.api.references.References/WriteFriendReference',
                request_serializer=references__pb2.WriteFriendReferenceReq.SerializeToString,
                response_deserializer=references__pb2.Reference.FromString,
                )
        self.WriteHostRequestReference = channel.unary_unary(
                '/org.couchers.api.references.References/WriteHostRequestReference',
                request_serializer=references__pb2.WriteHostRequestReferenceReq.SerializeToString,
                response_deserializer=references__pb2.Reference.FromString,
                )
        self.HostRequestIndicateDidntMeetup = channel.unary_unary(
                '/org.couchers.api.references.References/HostRequestIndicateDidntMeetup',
                request_serializer=references__pb2.HostRequestIndicateDidntMeetupReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AvailableWriteReferences = channel.unary_unary(
                '/org.couchers.api.references.References/AvailableWriteReferences',
                request_serializer=references__pb2.AvailableWriteReferencesReq.SerializeToString,
                response_deserializer=references__pb2.AvailableWriteReferencesRes.FromString,
                )
        self.ListPendingReferencesToWrite = channel.unary_unary(
                '/org.couchers.api.references.References/ListPendingReferencesToWrite',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=references__pb2.ListPendingReferencesToWriteRes.FromString,
                )
        self.GetHostRequestReferenceStatus = channel.unary_unary(
                '/org.couchers.api.references.References/GetHostRequestReferenceStatus',
                request_serializer=references__pb2.GetHostRequestReferenceStatusReq.SerializeToString,
                response_deserializer=references__pb2.GetHostRequestReferenceStatusRes.FromString,
                )


class ReferencesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListReferences(self, request, context):
        """Returns a paginated list of references satisfying some filtering criterion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteFriendReference(self, request, context):
        """Write a reference for your friend. Raises INVALID_ARGUMENT if you
        try to write for yourself, or NOT_FOUND if the user doesn't exist.
        Raises FAILED_PRECONDITION if you try to write a reference for someone you already wrote a friend reference for.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WriteHostRequestReference(self, request, context):
        """Write a reference for someone after having hosted/surfed with them. Raises NOT_FOUND if the request doesn't
        exist.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HostRequestIndicateDidntMeetup(self, request, context):
        """Indicate that the user didn't meet up
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AvailableWriteReferences(self, request, context):
        """Return the reference types that is, at the moment, possible to write about a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPendingReferencesToWrite(self, request, context):
        """Returns a list of references that you should write about others, e.g. after surfing or hosting
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetHostRequestReferenceStatus(self, request, context):
        """Returns status for whether the current user can write a host-request reference for the given request id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReferencesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReferences,
                    request_deserializer=references__pb2.ListReferencesReq.FromString,
                    response_serializer=references__pb2.ListReferencesRes.SerializeToString,
            ),
            'WriteFriendReference': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteFriendReference,
                    request_deserializer=references__pb2.WriteFriendReferenceReq.FromString,
                    response_serializer=references__pb2.Reference.SerializeToString,
            ),
            'WriteHostRequestReference': grpc.unary_unary_rpc_method_handler(
                    servicer.WriteHostRequestReference,
                    request_deserializer=references__pb2.WriteHostRequestReferenceReq.FromString,
                    response_serializer=references__pb2.Reference.SerializeToString,
            ),
            'HostRequestIndicateDidntMeetup': grpc.unary_unary_rpc_method_handler(
                    servicer.HostRequestIndicateDidntMeetup,
                    request_deserializer=references__pb2.HostRequestIndicateDidntMeetupReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AvailableWriteReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.AvailableWriteReferences,
                    request_deserializer=references__pb2.AvailableWriteReferencesReq.FromString,
                    response_serializer=references__pb2.AvailableWriteReferencesRes.SerializeToString,
            ),
            'ListPendingReferencesToWrite': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPendingReferencesToWrite,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=references__pb2.ListPendingReferencesToWriteRes.SerializeToString,
            ),
            'GetHostRequestReferenceStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetHostRequestReferenceStatus,
                    request_deserializer=references__pb2.GetHostRequestReferenceStatusReq.FromString,
                    response_serializer=references__pb2.GetHostRequestReferenceStatusRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.references.References', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class References(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/ListReferences',
            references__pb2.ListReferencesReq.SerializeToString,
            references__pb2.ListReferencesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteFriendReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/WriteFriendReference',
            references__pb2.WriteFriendReferenceReq.SerializeToString,
            references__pb2.Reference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WriteHostRequestReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/WriteHostRequestReference',
            references__pb2.WriteHostRequestReferenceReq.SerializeToString,
            references__pb2.Reference.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HostRequestIndicateDidntMeetup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/HostRequestIndicateDidntMeetup',
            references__pb2.HostRequestIndicateDidntMeetupReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AvailableWriteReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/AvailableWriteReferences',
            references__pb2.AvailableWriteReferencesReq.SerializeToString,
            references__pb2.AvailableWriteReferencesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPendingReferencesToWrite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/ListPendingReferencesToWrite',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            references__pb2.ListPendingReferencesToWriteRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetHostRequestReferenceStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.references.References/GetHostRequestReferenceStatus',
            references__pb2.GetHostRequestReferenceStatusReq.SerializeToString,
            references__pb2.GetHostRequestReferenceStatusRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x8e\x04\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12\x14\n\x0c\x64o_not_email\x18\x0f \x01(\x08\x12\x0e\n\x06\x62\x61\x64ges\x18\x08 \x03(\t\x12\x1f\n\x17has_strong_verification\x18\t \x01(\x08\x12Y\n\x1d\x62irthdate_verification_status\x18\n \x01(\x0e\x32\x32.org.couchers.api.core.BirthdateVerificationStatus\x12S\n\x1agender_verification_status\x18\x0b \x01(\x0e\x32/.org.couchers.api.core.GenderVerificationStatus\x12)\n!has_passport_sex_gender_exception\x18\x0c \x01(\x08\x12\x12\n\nadmin_note\x18\r \x01(\t\x12\x1f\n\x17pending_mod_notes_count\x18\x10 \x01(\x03\x12$\n\x1c\x61\x63knowledged_mod_notes_count\x18\x11 \x01(\x03\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1a\n\nGetUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x86\x04\n\x0eSearchUsersReq\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nadmin_note\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\x12\x13\n\x0bmin_user_id\x18\x08 \x01(\x03\x12\x13\n\x0bmax_user_id\x18\t \x01(\x03\x12\x15\n\rmin_birthdate\x18\n \x01(\t\x12\x15\n\rmax_birthdate\x18\x0b \x01(\t\x12\x17\n\x0fmin_joined_date\x18\x0c \x01(\t\x12\x17\n\x0fmax_joined_date\x18\r \x01(\t\x12\x1c\n\x14min_last_active_date\x18\x0e \x01(\t\x12\x1c\n\x14max_last_active_date\x18\x0f \x01(\t\x12\x0f\n\x07genders\x18\x10 \x03(\t\x12\x16\n\x0elanguage_codes\x18\x11 \x03(\t\x12.\n\nis_deleted\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tis_banned\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nhas_avatar\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"Y\n\x0eSearchUsersRes\x12.\n\x05users\x18\x01 \x03(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"-\n\x0b\x41\x64\x64\x42\x61\x64geReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"0\n\x0eRemoveBadgeReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"W\n SetPassportSexGenderExceptionReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12%\n\x1dpassport_sex_gender_exception\x18\x02 \x01(\x08\".\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"0\n\x0cUnbanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"3\n\x0f\x41\x64\x64\x41\x64minNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"\xe3\x01\n\rContentReport\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11reporting_user_id\x18\x03 \x01(\x03\x12\x16\n\x0e\x61uthor_user_id\x18\x04 \x01(\x03\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x07 \x01(\t\x12\x12\n\nuser_agent\x18\x08 \x01(\t\x12\x0c\n\x04page\x18\t \x01(\t\"0\n\x13GetContentReportReq\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\"P\n\x13GetContentReportRes\x12\x39\n\x0e\x63ontent_report\x18\x01 \x01(\x0b\x32!.org.couchers.admin.ContentReport\"-\n\x1dGetContentReportsForAuthorReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"[\n\x1dGetContentReportsForAuthorRes\x12:\n\x0f\x63ontent_reports\x18\x01 \x03(\x0b\x32!.org.couchers.admin.ContentReport\"[\n\x0eSendModNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0binternal_id\x18\x03 \x01(\t\x12\x15\n\rdo_not_notify\x18\x04 \x01(\x08\".\n\x1eMarkUserNeedsLocationUpdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"%\n\x15RecoverDeletedUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x1b\n\x0bGetChatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\xf5\x01\n\x0b\x43hatMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x12/\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cmessage_type\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\"\n\x1ahost_request_status_target\x18\x06 \x01(\t\x12/\n\x06target\x18\x07 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\"\xa4\x01\n\x0fGroupChatMember\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12*\n\x06joined\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04left\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04role\x18\x04 \x01(\t\"\xe0\x01\n\x0e\x41\x64minGroupChat\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05is_dm\x18\x03 \x01(\x08\x12\x30\n\x07\x63reator\x18\x04 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x34\n\x07members\x18\x05 \x03(\x0b\x32#.org.couchers.admin.GroupChatMember\x12\x31\n\x08messages\x18\x06 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\x9f\x02\n\x10\x41\x64minHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12/\n\x06surfer\x18\x02 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12-\n\x04host\x18\x03 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tfrom_date\x18\x05 \x01(\t\x12\x0f\n\x07to_date\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x08messages\x18\x08 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\xb2\x01\n\x0bGetChatsRes\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12;\n\rhost_requests\x18\x02 \x03(\x0b\x32$.org.couchers.admin.AdminHostRequest\x12\x37\n\x0bgroup_chats\x18\x03 \x03(\x0b\x32\".org.couchers.admin.AdminGroupChat\"\"\n\x0e\x44\x65leteEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"\x95\x01\n\x0eListUserIdsReq\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\";\n\x0eListUserIdsRes\x12\x10\n\x08user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\">\n\x14\x45\x64itReferenceTextReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x10\n\x08new_text\x18\x02 \x01(\t\"*\n\x12\x44\x65leteReferenceReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\"R\n\x11\x45\x64itDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x11\n\tnew_title\x18\x02 \x01(\t\x12\x13\n\x0bnew_content\x18\x03 \x01(\t\"5\n\x0c\x45\x64itReplyReq\x12\x10\n\x08reply_id\x18\x01 \x01(\x03\x12\x13\n\x0bnew_content\x18\x02 \x01(\t\"L\n\x1f\x41\x64\x64UsersToModerationUserListReq\x12\r\n\x05users\x18\x01 \x03(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"*\n\x1aListModerationUserListsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"@\n\x0eModerationList\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\x12\x12\n\nmember_ids\x18\x02 \x03(\x03\"Z\n\x1aListModerationUserListsRes\x12<\n\x10moderation_lists\x18\x01 \x03(\x0b\x32\".org.couchers.admin.ModerationList\"=\n\x1f\x41\x64\x64UsersToModerationUserListRes\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\"O\n#RemoveUserFromModerationUserListReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"A\n\x1c\x43reateAccountDeletionLinkReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x13\n\x0b\x65xpiry_days\x18\x02 \x01(\x03\"D\n\x1c\x43reateAccountDeletionLinkRes\x12$\n\x1c\x61\x63\x63ount_deletion_confirm_url\x18\x01 \x01(\t\"|\n\x0e\x41\x63\x63\x65ssStatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xca\x02\n\nAccessStat\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0b\n\x03\x61sn\x18\x02 \x01(\t\x12\r\n\x05\x61sorg\x18\x03 \x01(\t\x12\x11\n\tasnetwork\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x18\n\x10operating_system\x18\x06 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x07 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x08 \x01(\t\x12\x1c\n\x14\x61pproximate_location\x18\t \x01(\t\x12\x16\n\x0e\x61pi_call_count\x18\n \x01(\x04\x12\x15\n\rperiods_count\x18\x0b \x01(\x04\x12.\n\nfirst_seen\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x0e\x41\x63\x63\x65ssStatsRes\x12-\n\x05stats\x18\x01 \x03(\x0b\x32\x1e.org.couchers.admin.AccessStat\"S\n\x11SetLastDonatedReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x30\n\x0clast_donated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xb3\x17\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12H\n\x07GetUser\x12\x1e.org.couchers.admin.GetUserReq\x1a\x1b.org.couchers.api.core.User\"\x00\x12W\n\x0bSearchUsers\x12\".org.couchers.admin.SearchUsersReq\x1a\".org.couchers.admin.SearchUsersRes\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12N\n\x08\x41\x64\x64\x42\x61\x64ge\x12\x1f.org.couchers.admin.AddBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12T\n\x0bRemoveBadge\x12\".org.couchers.admin.RemoveBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12x\n\x1dSetPassportSexGenderException\x12\x34.org.couchers.admin.SetPassportSexGenderExceptionReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12P\n\tUnbanUser\x12 .org.couchers.admin.UnbanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12V\n\x0c\x41\x64\x64\x41\x64minNote\x12#.org.couchers.admin.AddAdminNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x66\n\x10GetContentReport\x12\'.org.couchers.admin.GetContentReportReq\x1a\'.org.couchers.admin.GetContentReportRes\"\x00\x12\x84\x01\n\x1aGetContentReportsForAuthor\x12\x31.org.couchers.admin.GetContentReportsForAuthorReq\x1a\x31.org.couchers.admin.GetContentReportsForAuthorRes\"\x00\x12T\n\x0bSendModNote\x12\".org.couchers.admin.SendModNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12t\n\x1bMarkUserNeedsLocationUpdate\x12\x32.org.couchers.admin.MarkUserNeedsLocationUpdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x62\n\x12RecoverDeletedUser\x12).org.couchers.admin.RecoverDeletedUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12N\n\x08GetChats\x12\x1f.org.couchers.admin.GetChatsReq\x1a\x1f.org.couchers.admin.GetChatsRes\"\x00\x12K\n\x0b\x44\x65leteEvent\x12\".org.couchers.admin.DeleteEventReq\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0bListUserIds\x12\".org.couchers.admin.ListUserIdsReq\x1a\".org.couchers.admin.ListUserIdsRes\"\x00\x12W\n\x11\x45\x64itReferenceText\x12(.org.couchers.admin.EditReferenceTextReq\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0f\x44\x65leteReference\x12&.org.couchers.admin.DeleteReferenceReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0e\x45\x64itDiscussion\x12%.org.couchers.admin.EditDiscussionReq\x1a\x16.google.protobuf.Empty\"\x00\x12G\n\tEditReply\x12 .org.couchers.admin.EditReplyReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x8a\x01\n\x1c\x41\x64\x64UsersToModerationUserList\x12\x33.org.couchers.admin.AddUsersToModerationUserListReq\x1a\x33.org.couchers.admin.AddUsersToModerationUserListRes\"\x00\x12u\n RemoveUserFromModerationUserList\x12\x37.org.couchers.admin.RemoveUserFromModerationUserListReq\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x17ListModerationUserLists\x12..org.couchers.admin.ListModerationUserListsReq\x1a..org.couchers.admin.ListModerationUserListsRes\"\x00\x12\x81\x01\n\x19\x43reateAccountDeletionLink\x12\x30.org.couchers.admin.CreateAccountDeletionLinkReq\x1a\x30.org.couchers.admin.CreateAccountDeletionLinkRes\"\x00\x12W\n\x0b\x41\x63\x63\x65ssStats\x12\".org.couchers.admin.AccessStatsReq\x1a\".org.couchers.admin.AccessStatsRes\"\x00\x12Z\n\x0eSetLastDonated\x12%.org.couchers.admin.SetLastDonatedReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\210\265\030\004'
  _globals['_USERDETAILS']._serialized_start=160
  _globals['_USERDETAILS']._serialized_end=686
  _globals['_GETUSERDETAILSREQ']._serialized_start=688
  _globals['_GETUSERDETAILSREQ']._serialized_end=721
  _globals['_GETUSERREQ']._serialized_start=723
  _globals['_GETUSERREQ']._serialized_end=749
  _globals['_SEARCHUSERSREQ']._serialized_start=752
  _globals['_SEARCHUSERSREQ']._serialized_end=1270
  _globals['_SEARCHUSERSRES']._serialized_start=1272
  _globals['_SEARCHUSERSRES']._serialized_end=1361
  _globals['_CHANGEUSERGENDERREQ']._serialized_start=1363
  _globals['_CHANGEUSERGENDERREQ']._serialized_end=1414
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_start=1416
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_end=1473
  _globals['_ADDBADGEREQ']._serialized_start=1475
  _globals['_ADDBADGEREQ']._serialized_end=1520
  _globals['_REMOVEBADGEREQ']._serialized_start=1522
  _globals['_REMOVEBADGEREQ']._serialized_end=1570
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_start=1572
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_end=1659
  _globals['_BANUSERREQ']._serialized_start=1661
  _globals['_BANUSERREQ']._serialized_end=1707
  _globals['_UNBANUSERREQ']._serialized_start=1709
  _globals['_UNBANUSERREQ']._serialized_end=1757
  _globals['_ADDADMINNOTEREQ']._serialized_start=1759
  _globals['_ADDADMINNOTEREQ']._serialized_end=1810
  _globals['_CONTENTREPORT']._serialized_start=1813
  _globals['_CONTENTREPORT']._serialized_end=2040
  _globals['_GETCONTENTREPORTREQ']._serialized_start=2042
  _globals['_GETCONTENTREPORTREQ']._serialized_end=2090
  _globals['_GETCONTENTREPORTRES']._serialized_start=2092
  _globals['_GETCONTENTREPORTRES']._serialized_end=2172
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_start=2174
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_end=2219
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_start=2221
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_end=2312
  _globals['_SENDMODNOTEREQ']._serialized_start=2314
  _globals['_SENDMODNOTEREQ']._serialized_end=2405
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_start=2407
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_end=2453
  _globals['_DELETEUSERREQ']._serialized_start=2455
  _globals['_DELETEUSERREQ']._serialized_end=2484
  _globals['_RECOVERDELETEDUSERREQ']._serialized_start=2486
  _globals['_RECOVERDELETEDUSERREQ']._serialized_end=2523
  _globals['_CREATEAPIKEYREQ']._serialized_start=2525
  _globals['_CREATEAPIKEYREQ']._serialized_end=2556
  _globals['_CREATEAPIKEYRES']._serialized_start=2558
  _globals['_CREATEAPIKEYRES']._serialized_end=2575
  _globals['_GETCHATSREQ']._serialized_start=2577
  _globals['_GETCHATSREQ']._serialized_end=2604
  _globals['_CHATMESSAGE']._serialized_start=2607
  _globals['_CHATMESSAGE']._serialized_end=2852
  _globals['_GROUPCHATMEMBER']._serialized_start=2855
  _globals['_GROUPCHATMEMBER']._serialized_end=3019
  _globals['_ADMINGROUPCHAT']._serialized_start=3022
  _globals['_ADMINGROUPCHAT']._serialized_end=3246
  _globals['_ADMINHOSTREQUEST']._serialized_start=3249
  _globals['_ADMINHOSTREQUEST']._serialized_end=3536
  _globals['_GETCHATSRES']._serialized_start=3539
  _globals['_GETCHATSRES']._serialized_end=3717
  _globals['_DELETEEVENTREQ']._serialized_start=3719
  _globals['_DELETEEVENTREQ']._serialized_end=3753
  _globals['_LISTUSERIDSREQ']._serialized_start=3756
  _globals['_LISTUSERIDSREQ']._serialized_end=3905
  _globals['_LISTUSERIDSRES']._serialized_start=3907
  _globals['_LISTUSERIDSRES']._serialized_end=3966
  _globals['_EDITREFERENCETEXTREQ']._serialized_start=3968
  _globals['_EDITREFERENCETEXTREQ']._serialized_end=4030
  _globals['_DELETEREFERENCEREQ']._serialized_start=4032
  _globals['_DELETEREFERENCEREQ']._serialized_end=4074
  _globals['_EDITDISCUSSIONREQ']._serialized_start=4076
  _globals['_EDITDISCUSSIONREQ']._serialized_end=4158
  _globals['_EDITREPLYREQ']._serialized_start=4160
  _globals['_EDITREPLYREQ']._serialized_end=4213
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_start=4215
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_end=4291
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_start=4293
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_end=4335
  _globals['_MODERATIONLIST']._serialized_start=4337
  _globals['_MODERATIONLIST']._serialized_end=4401
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_start=4403
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_end=4493
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_start=4495
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_end=4556
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_start=4558
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_end=4637
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_start=4639
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_end=4704
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_start=4706
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_end=4774
  _globals['_ACCESSSTATSREQ']._serialized_start=4776
  _globals['_ACCESSSTATSREQ']._serialized_end=4900
  _globals['_ACCESSSTAT']._serialized_start=4903
  _globals['_ACCESSSTAT']._serialized_end=5233
  _globals['_ACCESSSTATSRES']._serialized_start=5235
  _globals['_ACCESSSTATSRES']._serialized_end=5298
  _globals['_SETLASTDONATEDREQ']._serialized_start=5300
  _globals['_SETLASTDONATEDREQ']._serialized_end=5383
  _globals['_ADMIN']._serialized_start=5386
  _globals['_ADMIN']._serialized_end=8381
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import moderation_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class ModerationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetModerationQueue(
        self,
        request: moderation_pb2.GetModerationQueueReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationQueueRes, collections.abc.Awaitable[moderation_pb2.GetModerationQueueRes]]: ...

    @abc.abstractmethod
    def GetModerationState(
        self,
        request: moderation_pb2.GetModerationStateReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationStateRes, collections.abc.Awaitable[moderation_pb2.GetModerationStateRes]]: ...

    @abc.abstractmethod
    def GetModerationLog(
        self,
        request: moderation_pb2.GetModerationLogReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationLogRes, collections.abc.Awaitable[moderation_pb2.GetModerationLogRes]]: ...

    @abc.abstractmethod
    def ModerateContent(
        self,
        request: moderation_pb2.ModerateContentReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.ModerateContentRes, collections.abc.Awaitable[moderation_pb2.ModerateContentRes]]: ...

    @abc.abstractmethod
    def FlagContentForReview(
        self,
        request: moderation_pb2.FlagContentForReviewReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.FlagContentForReviewRes, collections.abc.Awaitable[moderation_pb2.FlagContentForReviewRes]]: ...

    @abc.abstractmethod
    def UnflagContent(
        self,
        request: moderation_pb2.UnflagContentReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.UnflagContentRes, collections.abc.Awaitable[moderation_pb2.UnflagContentRes]]: ...

def add_ModerationServicer_to_server(servicer: ModerationServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import discussions_pb2 as discussions__pb2


class DiscussionsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDiscussion = channel.unary_unary(
                '/org.couchers.api.discussions.Discussions/CreateDiscussion',
                request_serializer=discussions__pb2.CreateDiscussionReq.SerializeToString,
                response_deserializer=discussions__pb2.Discussion.FromString,
                )
        self.GetDiscussion = channel.unary_unary(
                '/org.couchers.api.discussions.Discussions/GetDiscussion',
                request_serializer=discussions__pb2.GetDiscussionReq.SerializeToString,
                response_deserializer=discussions__pb2.Discussion.FromString,
                )


class DiscussionsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDiscussion(self, request, context):
        """Create a new discussion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDiscussion(self, request, context):
        """Retrieve a discussion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiscussionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDiscussion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDiscussion,
                    request_deserializer=discussions__pb2.CreateDiscussionReq.FromString,
                    response_serializer=discussions__pb2.Discussion.SerializeToString,
            ),
            'GetDiscussion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDiscussion,
                    request_deserializer=discussions__pb2.GetDiscussionReq.FromString,
                    response_serializer=discussions__pb2.Discussion.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.discussions.Discussions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Discussions(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDiscussion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.discussions.Discussions/CreateDiscussion',
            discussions__pb2.CreateDiscussionReq.SerializeToString,
            discussions__pb2.Discussion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDiscussion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.discussions.Discussions/GetDiscussion',
            discussions__pb2.GetDiscussionReq.SerializeToString,
            discussions__pb2.Discussion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import feature_requests_pb2 as feature__requests__pb2


class FeatureRequestsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeatureRequests = channel.unary_unary(
                '/org.couchers.api.feature_requests.FeatureRequests/GetFeatureRequests',
                request_serializer=feature__requests__pb2.GetFeatureRequestsReq.SerializeToString,
                response_deserializer=feature__requests__pb2.GetFeatureRequestsRes.FromString,
                )
        self.CreateFeatureRequest = channel.unary_unary(
                '/org.couchers.api.feature_requests.FeatureRequests/CreateFeatureRequest',
                request_serializer=feature__requests__pb2.CreateFeatureRequestReq.SerializeToString,
                response_deserializer=feature__requests__pb2.FeatureRequest.FromString,
                )
        self.VoteOnFeatureRequest = channel.unary_unary(
                '/org.couchers.api.feature_requests.FeatureRequests/VoteOnFeatureRequest',
                request_serializer=feature__requests__pb2.VoteOnFeatureRequestReq.SerializeToString,
                response_deserializer=feature__requests__pb2.FeatureRequest.FromString,
                )


class FeatureRequestsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeatureRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteOnFeatureRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureRequestsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetFeatureRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureRequests,
                    request_deserializer=feature__requests__pb2.GetFeatureRequestsReq.FromString,
                    response_serializer=feature__requests__pb2.GetFeatureRequestsRes.SerializeToString,
            ),
            'CreateFeatureRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureRequest,
                    request_deserializer=feature__requests__pb2.CreateFeatureRequestReq.FromString,
                    response_serializer=feature__requests__pb2.FeatureRequest.SerializeToString,
            ),
            'VoteOnFeatureRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteOnFeatureRequest,
                    request_deserializer=feature__requests__pb2.VoteOnFeatureRequestReq.FromString,
                    response_serializer=feature__requests__pb2.FeatureRequest.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.feature_requests.FeatureRequests', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureRequests(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeatureRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_requests.FeatureRequests/GetFeatureRequests',
            feature__requests__pb2.GetFeatureRequestsReq.SerializeToString,
            feature__requests__pb2.GetFeatureRequestsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_requests.FeatureRequests/CreateFeatureRequest',
            feature__requests__pb2.CreateFeatureRequestReq.SerializeToString,
            feature__requests__pb2.FeatureRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteOnFeatureRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_requests.FeatureRequests/VoteOnFeatureRequest',
            feature__requests__pb2.VoteOnFeatureRequestReq.SerializeToString,
            feature__requests__pb2.FeatureRequest.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import api_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class APIServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Ping(
        self,
        request: api_pb2.PingReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.PingRes, collections.abc.Awaitable[api_pb2.PingRes]]:
        """Pings the server for updates and basic user info"""

    @abc.abstractmethod
    def GetUser(
        self,
        request: api_pb2.GetUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.User, collections.abc.Awaitable[api_pb2.User]]:
        """Get info about a particular user"""

    @abc.abstractmethod
    def GetLiteUser(
        self,
        request: api_pb2.GetLiteUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.LiteUser, collections.abc.Awaitable[api_pb2.LiteUser]]:
        """Get minimal info about a particular user"""

    @abc.abstractmethod
    def GetLiteUsers(
        self,
        request: api_pb2.GetLiteUsersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.GetLiteUsersRes, collections.abc.Awaitable[api_pb2.GetLiteUsersRes]]:
        """Get minimal info about a bunch of users"""

    @abc.abstractmethod
    def UpdateProfile(
        self,
        request: api_pb2.UpdateProfileReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Update your profile
        *Nullable can be set to null to clear the value. is_null defaults to false.
        """

    @abc.abstractmethod
    def SendFriendRequest(
        self,
        request: api_pb2.SendFriendRequestReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def ListFriendRequests(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.ListFriendRequestsRes, collections.abc.Awaitable[api_pb2.ListFriendRequestsRes]]: ...

    @abc.abstractmethod
    def ListFriends(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.ListFriendsRes, collections.abc.Awaitable[api_pb2.ListFriendsRes]]: ...

    @abc.abstractmethod
    def RemoveFriend(
        self,
        request: api_pb2.RemoveFriendReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def ListMutualFriends(
        self,
        request: api_pb2.ListMutualFriendsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.ListMutualFriendsRes, collections.abc.Awaitable[api_pb2.ListMutualFriendsRes]]:
        """List mutual friends between requester and requested user
        When called on self, returns empty list
        """

    @abc.abstractmethod
    def RespondFriendRequest(
        self,
        request: api_pb2.RespondFriendRequestReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def CancelFriendRequest(
        self,
        request: api_pb2.CancelFriendRequestReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def InitiateMediaUpload(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.InitiateMediaUploadRes, collections.abc.Awaitable[api_pb2.InitiateMediaUploadRes]]:
        """Initiate a media upload"""

    @abc.abstractmethod
    def ListBadgeUsers(
        self,
        request: api_pb2.ListBadgeUsersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[api_pb2.ListBadgeUsersRes, collections.abc.Awaitable[api_pb2.ListBadgeUsersRes]]:
        """Lists users with a given badge"""

def add_APIServicer_to_server(servicer: APIServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import account_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class AccountServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetAccountInfoRes, collections.abc.Awaitable[account_pb2.GetAccountInfoRes]]:
        """account management APIs
        Get information about the user's account
        """

    @abc.abstractmethod
    def ChangePasswordV2(
        self,
        request: account_pb2.ChangePasswordV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Change the user's password
        we will send and an email to the user saying their password was changed
        """

    @abc.abstractmethod
    def ChangeEmailV2(
        self,
        request: account_pb2.ChangeEmailV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Change the user's email address
        We will send a notification email to the old email, and confirmation email to the new email
        Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
        """

    @abc.abstractmethod
    def GetContributorFormInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetContributorFormInfoRes, collections.abc.Awaitable[account_pb2.GetContributorFormInfoRes]]:
        """Returns info related to filling out the contributor form"""

    @abc.abstractmethod
    def FillContributorForm(
        self,
        request: account_pb2.FillContributorFormReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Fill the contributor form; this can be done multiple times"""

    @abc.abstractmethod
    def ChangeLanguagePreference(
        self,
        request: account_pb2.ChangeLanguagePreferenceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Changes the user's interface language"""

    @abc.abstractmethod
    def ChangePhone(
        self,
        request: account_pb2.ChangePhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
        And returned in a call to in VerifyPhone() to complete the phone number change.
        An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
        A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
        An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
        """

    @abc.abstractmethod
    def VerifyPhone(
        self,
        request: account_pb2.VerifyPhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Enter the code you got in the sms. Other accounts using the same phone number will
        lose their verification status.
        """

    @abc.abstractmethod
    def InitiateStrongVerification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.InitiateStrongVerificationRes, collections.abc.Awaitable[account_pb2.InitiateStrongVerificationRes]]:
        """Initiates a strong verification (passport read)"""

    @abc.abstractmethod
    def GetStrongVerificationAttemptStatus(
        self,
        request: account_pb2.GetStrongVerificationAttemptStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetStrongVerificationAttemptStatusRes, collections.abc.Awaitable[account_pb2.GetStrongVerificationAttemptStatusRes]]:
        """Gets the status of a strong verification attempt"""

    @abc.abstractmethod
    def DeleteStrongVerificationData(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Deletes full SV data (but not minimal data), see the ToS"""

    @abc.abstractmethod
    def DeleteAccount(
        self,
        request: account_pb2.DeleteAccountReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Sends email with confirmation link containing token to delete account"""

    @abc.abstractmethod
    def ListModNotes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListModNotesRes, collections.abc.Awaitable[account_pb2.ListModNotesRes]]:
        """Lists all the user's mod notes: only ack'd ones because otherwise the user is jailed"""

    @abc.abstractmethod
    def ListActiveSessions(
        self,
        request: account_pb2.ListActiveSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListActiveSessionsRes, collections.abc.Awaitable[account_pb2.ListActiveSessionsRes]]:
        """Lists all the user's current sessions"""

    @abc.abstractmethod
    def LogOutSession(
        self,
        request: account_pb2.LogOutSessionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Logs the user out of the given session, cannot be current one"""

    @abc.abstractmethod
    def LogOutOtherSessions(
        self,
        request: account_pb2.LogOutOtherSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Logs the user out of all other sessions except this one"""

    @abc.abstractmethod
    def SetProfilePublicVisibility(
        self,
        request: account_pb2.SetProfilePublicVisibilityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Set what info is shown to logged-out users"""

    @abc.abstractmethod
    def CreateInviteCode(
        self,
        request: account_pb2.CreateInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.CreateInviteCodeRes, collections.abc.Awaitable[account_pb2.CreateInviteCodeRes]]:
        """Creates a new unique invite code for the current user"""

    @abc.abstractmethod
    def DisableInviteCode(
        self,
        request: account_pb2.DisableInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Disables the given invite code created by the user"""

    @abc.abstractmethod
    def ListInviteCodes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListInviteCodesRes, collections.abc.Awaitable[account_pb2.ListInviteCodesRes]]:
        """Lists all invite codes created by the user, with usage count"""

    @abc.abstractmethod
    def GetReminders(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetRemindersRes, collections.abc.Awaitable[account_pb2.GetRemindersRes]]:
        """Reminders to be shown on dashboard for things the user should do"""

    @abc.abstractmethod
    def GetMyVolunteerInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetMyVolunteerInfoRes, collections.abc.Awaitable[account_pb2.GetMyVolunteerInfoRes]]:
        """Returns info about the current user's volunteer status if they are volunteer"""

    @abc.abstractmethod
    def UpdateMyVolunteerInfo(
        self,
        request: account_pb2.UpdateMyVolunteerInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetMyVolunteerInfoRes, collections.abc.Awaitable[account_pb2.GetMyVolunteerInfoRes]]:
        """Updates the current user's volunteer status if they are volunteer"""

def add_AccountServicer_to_server(servicer: AccountServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
